@@ -74,8 +74,8 @@ GameView::GameView( QWidget *parent, GameLogic *gameLogic )
                            col.dark(75),       col.dark(75), col.dark(), 
                            Qt::black );
     palette.setColorGroup( QPalette::Disabled, Qt::white,    Qt::black,
-                           col.light(),        col.dark(),   col, 
-                           col.dark(75),       col.dark(75), col.dark(),
+                           col.light(),        col.dark(),   col,
+                           col.dark(75),       col.dark(75), Qt::black,
                            Qt::black );
     
     blackPal.setColor( QPalette::Base, Qt::black );
@@ -88,7 +88,8 @@ GameView::GameView( QWidget *parent, GameLogic *gameLogic )
     m_mapScene  = new MapScene(m_gameLogic->map());
     m_mapWidget = new MapView( m_mapScene );
     m_mapWidget->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
-    
+    m_mapWidget->setFrameShape(QFrame::NoFrame);
+
     m_msgWidget = new QTextEdit( this );
     m_msgWidget->setMaximumHeight(75);
     m_msgWidget->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
@@ -264,7 +265,7 @@ GameView::turn()
             turn();
 
         } else {
-            m_shipCountEdit->hide();
+            m_shipCountEdit->setEnabled(false);
             m_endTurnBtn->setEnabled( true );
             m_mapScene->unselectPlanet();
             m_gameMessage->setText( "<qt>" 
@@ -284,7 +285,7 @@ GameView::turn()
             m_guiState = SHIP_COUNT;
             turn();
         } else {
-            m_shipCountEdit->hide();
+            m_shipCountEdit->setEnabled(false);
             m_endTurnBtn->setEnabled( false );
             sourcePlanet->select();
             m_gameMessage->setText( "<qt>"
@@ -303,7 +304,7 @@ GameView::turn()
             // We now have a complete fleet to send, so send it
             sendAttackFleet( sourcePlanet, destPlanet, shipCount);
 
-            m_shipCountEdit->hide();
+            m_shipCountEdit->setEnabled(false);
             m_endTurnBtn->setEnabled( true );
 
             m_guiState = NONE;
@@ -312,11 +313,10 @@ GameView::turn()
             m_endTurnBtn->setFocus();
 
         } else {
-            m_gameMessage->setText( m_gameLogic->currentPlayer()->name() +
+            m_gameMessage->setText( m_gameLogic->currentPlayer()->coloredName() +
                                     i18n(": How many ships?") );
 
             m_shipCountEdit->setText( "" );
-            m_shipCountEdit->show();
             m_shipCountEdit->setEnabled(true);
             m_shipCountEdit->setFocus();
 
@@ -334,7 +334,7 @@ GameView::turn()
             sourcePlanet->select();
             turn();
         } else {
-            m_shipCountEdit->hide();
+            m_shipCountEdit->setEnabled(false);
             m_endTurnBtn->setEnabled( true );
             m_mapScene->unselectPlanet();
 
@@ -364,7 +364,7 @@ GameView::turn()
             turn();
         } else {
             m_gameMessage->setText( i18n("Ruler: Select ending planet.") );
-            m_shipCountEdit->hide();
+            m_shipCountEdit->setEnabled(false);
             m_endTurnBtn->setEnabled( false );
             sourcePlanet->select();
 
@@ -517,13 +517,22 @@ GameView::startNewGame()
     //        call to newGame->exec().  Change that.
     m_gameLogic->startNewGame();
 
-    // Set up the GUI for a new game.
+    // Set up the base GUI for a new game.
     m_msgWidget->clear();
-    m_shipCountEdit->hide();
+    m_shipCountEdit->show();
+    m_shipCountEdit->setEnabled(true);
+    
+    // If the first player is a computer, don't set the GUI...
+    while (m_gameInProgress && m_gameLogic->currentPlayer()->isAiPlayer())
+    {
+        dynamic_cast<AIPlayer *>(m_gameLogic->currentPlayer())
+            ->doMove(m_gameLogic);
+        m_gameLogic->nextPlayer();
+    }
+    // Now it's a human playing...
     m_endTurnBtn->setEnabled( true );
     m_endTurnBtn->show();
     m_gameMessage->show();
-
     turn();
 
     delete newGame;
@@ -687,13 +696,11 @@ GameView::changeGameView( bool inPlay  )
 // Player clicked the 'End Turn' button
 //************************************************************************
 
-
-// FIXME: the handling of AI players should NOT be in gameview.
-
 void
 GameView::nextPlayer()
 {
     m_gameLogic->nextPlayer();
+    m_mapScene->update();
 
     // Let the AI players do their stuff
     while (m_gameInProgress 
