@@ -521,7 +521,7 @@ void MyMainView::newRound()
    //field.update();
 
    QString str = i18n("Press %1 to start",
-                  KShortcut(GAME_START_SHORTCUT).toString());
+                  KShortcut(GAME_START_SHORTCUT).primary().toString(QKeySequence::NativeText));
    emit(setStatusText(str,IDS_MAIN));
    emit(setStatusText( "", IDS_PAUSE ));
    stop( );
@@ -588,7 +588,7 @@ void MyMainView::timerEvent(QTimerEvent *event)
             textSprite->setPos(QPointF((width()-textSprite->boundingRect().width()) / 2,height()/2-90));
             
             QString str = i18n("Press %1 for new round",
-                           KShortcut(GAME_START_SHORTCUT).toString());
+                           KShortcut(GAME_START_SHORTCUT).primary().toString(QKeySequence::NativeText));
             emit(setStatusText(str,IDS_MAIN));
             stop( );
          }
